==> react-swipeable-views-0.1.6.tgz: package/lib/index.js <==
'use strict';

var React = require('react');
var PureRenderMixin = require('react/lib/ReactComponentWithPureRenderMixin');

var _require = require('react-motion');

var Spring = _require.Spring;

var objectAssign = require('object-assign');

var styles = {
  root: {
    overflowX: 'hidden'
  },
  container: {
    display: 'flex'
  },
  slide: {
    width: '100%',
    flexShrink: 0,
    overflow: 'auto'
  }
};

var SwipeableViews = React.createClass({
  displayName: 'SwipeableViews',

  propTypes: {
    children: React.PropTypes.node,
    index: React.PropTypes.number,
    onChangeIndex: React.PropTypes.func,
    style: React.PropTypes.object
  },
  mixins: [PureRenderMixin],
  getDefaultProps: function getDefaultProps() {
    return {
      index: 0
    };
  },
  getInitialState: function getInitialState() {
    return {
      index: this.props.index,
      isDragging: false,
      isFirstRender: true
    };
  },
  componentDidMount: function componentDidMount() {
    this.setState({
      isFirstRender: false
    });
  },
  componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
    var index = nextProps.index;

    if (typeof index === 'number' && index !== this.props.index) {
      this.setState({
        index: index
      });
    }
  },
  handleTouchStart: function handleTouchStart(event) {
    var touch = event.touches[0];

    this.startWidth = React.findDOMNode(this).getBoundingClientRect().width;
    this.startIndex = this.state.index;
    this.startX = touch.pageX;
    this.lastX = touch.pageX;
    this.deltaX = 0;
    this.startY = touch.pageY;
    this.isScroll = undefined;
  },
  handleTouchMove: function handleTouchMove(event) {
    var touch = event.touches[0];

    // This is a one time test
    if (this.isScroll === undefined) {
      this.isScroll = Math.abs(this.startY - touch.pageY) > Math.abs(this.startX - touch.pageX);
    }

    if (this.isScroll) {
      return;
    }

    // Prevent native scrolling
    event.preventDefault();

    this.deltaX = touch.pageX - this.lastX;
    this.lastX = touch.pageX;

    var indexMax = React.Children.count(this.props.children) - 1;

    var index = this.startIndex + (this.startX - touch.pageX) / this.startWidth;

    if (index < 0) {
      index = 0;
    } else if (index > indexMax) {
      index = indexMax;
    }

    this.setState({
      isDragging: true,
      index: index
    });
  },
  handleTouchEnd: function handleTouchEnd() {
    if (this.isScroll) {
      return;
    }

    var indexNew = undefined;

    // Quick movement
    if (Math.abs(this.deltaX) > 10) {
      if (this.deltaX > 0) {
        indexNew = Math.floor(this.state.index);
      } else {
        indexNew = Math.ceil(this.state.index);
      }
    } else {
      // Some hysteresis with startIndex
      if (Math.abs(this.startIndex - this.state.index) > 0.6) {
        indexNew = Math.round(this.state.index);
      } else {
        indexNew = this.startIndex;
      }
    }

    this.setState({
      index: indexNew,
      isDragging: false
    });

    if (this.props.onChangeIndex && indexNew !== this.startIndex) {
      this.props.onChangeIndex(indexNew);
    }
  },
  renderContainer: function renderContainer(translate) {
    var _props = this.props;
    var children = _props.children;
    var style = _props.style;
    var isFirstRender = this.state.isFirstRender;

    var childrenToRender = undefined;

    if (isFirstRender) {
      childrenToRender = children[0];
    } else {
      childrenToRender = React.Children.map(children, function (element) {
        return React.createElement(
          'div',
          { style: styles.slide },
          element
        );
      });
    }

    return React.createElement(
      'div',
      { style: objectAssign({
          WebkitTransform: 'translate3d(' + translate + 'px, 0, 0)',
          transform: 'translate3d(-' + translate + '%, 0, 0)'
        }, styles.container, style) },
      childrenToRender
    );
  },
  render: function render() {
    var _this = this;

    var _state = this.state;
    var index = _state.index;
    var isDragging = _state.isDragging;

    var endValue = {
      val: index * 100,
      config: isDragging ? [3000, 50] : [300, 30]
    };

    return React.createElement(
      'div',
      { style: styles.root,
        onTouchStart: this.handleTouchStart, onTouchMove: this.handleTouchMove, onTouchEnd: this.handleTouchEnd },
      React.createElement(
        Spring,
        { endValue: endValue },
        function (interpolated) {
          return _this.renderContainer(interpolated.val);
        }
      )
    );
  }
});

module.exports = SwipeableViews;

==> react-swipeable-views-0.2.2.tgz: package/lib/index.js <==
'use strict';

var React = require('react');
var PureRenderMixin = require('react/lib/ReactComponentWithPureRenderMixin');

var _require = require('react-motion');

var Motion = _require.Motion;
var spring = _require.spring;

var objectAssign = require('object-assign');

var styles = {
  root: {
    overflowX: 'hidden'
  },
  container: {
    display: 'flex'
  },
  slide: {
    width: '100%',
    flexShrink: 0,
    overflow: 'auto'
  }
};

var SwipeableViews = React.createClass({
  displayName: 'SwipeableViews',

  propTypes: {
    children: React.PropTypes.node,

    /**
     * This is the index of the slide to show.
     * This is useful when you want to change the default slide shown.
     * Or when you have tabs linked to each slide
     */
    index: React.PropTypes.number,

    /**
     * This is callback prop. It's call by the
     * component when the shown slide change after a swipe made by the user.
     * This is useful when you have tabs linked to each slide.
     */
    onChangeIndex: React.PropTypes.func,

    /**
     * This is the inlined style that will be applied
     * to each slide container.
     */
    style: React.PropTypes.object,

    /**
     * This is the threshold used for detecting a quick swipe.
     * If the computed speed is above this value, the index change.
     */
    threshold: React.PropTypes.number
  },
  mixins: [PureRenderMixin],
  getDefaultProps: function getDefaultProps() {
    return {
      index: 0,
      threshold: 5
    };
  },
  getInitialState: function getInitialState() {
    return {
      index: this.props.index,
      isDragging: false,
      isFirstRender: true
    };
  },
  componentDidMount: function componentDidMount() {
    this.setState({
      isFirstRender: false
    });
  },
  componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
    var index = nextProps.index;

    if (typeof index === 'number' && index !== this.props.index) {
      this.setState({
        index: index
      });
    }
  },
  handleTouchStart: function handleTouchStart(event) {
    var touch = event.touches[0];

    this.startWidth = React.findDOMNode(this).getBoundingClientRect().width;
    this.startIndex = this.state.index;
    this.startX = touch.pageX;
    this.lastX = touch.pageX;
    this.deltaX = 0;
    this.startY = touch.pageY;
    this.isScroll = undefined;
  },
  handleTouchMove: function handleTouchMove(event) {
    var touch = event.touches[0];

    // This is a one time test
    if (this.isScroll === undefined) {
      this.isScroll = Math.abs(this.startY - touch.pageY) > Math.abs(this.startX - touch.pageX);
    }

    if (this.isScroll) {
      return;
    }

    // Prevent native scrolling
    event.preventDefault();

    this.deltaX = touch.pageX - this.lastX;
    this.lastX = touch.pageX;

    var indexMax = React.Children.count(this.props.children) - 1;

    var index = this.startIndex + (this.startX - touch.pageX) / this.startWidth;

    if (index < 0) {
      index = 0;
      this.startX = touch.pageX;
    } else if (index > indexMax) {
      index = indexMax;
      this.startX = touch.pageX;
    }

    this.setState({
      isDragging: true,
      index: index
    });
  },
  handleTouchEnd: function handleTouchEnd() {
    if (this.isScroll) {
      return;
    }

    var indexNew = undefined;

    // Quick movement
    if (Math.abs(this.deltaX) > this.props.threshold) {
      if (this.deltaX > 0) {
        indexNew = Math.floor(this.state.index);
      } else {
        indexNew = Math.ceil(this.state.index);
      }
    } else {
      // Some hysteresis with startIndex
      if (Math.abs(this.startIndex - this.state.index) > 0.6) {
        indexNew = Math.round(this.state.index);
      } else {
        indexNew = this.startIndex;
      }
    }

    this.setState({
      index: indexNew,
      isDragging: false
    });

    if (this.props.onChangeIndex && indexNew !== this.startIndex) {
      this.props.onChangeIndex(indexNew);
    }
  },
  renderContainer: function renderContainer(translate) {
    var _props = this.props;
    var children = _props.children;
    var style = _props.style;
    var isFirstRender = this.state.isFirstRender;

    var childrenToRender = undefined;

    if (isFirstRender) {
      childrenToRender = children[0];
    } else {
      childrenToRender = React.Children.map(children, function (element) {
        return React.createElement(
          'div',
          { style: styles.slide },
          element
        );
      });
    }

    return React.createElement(
      'div',
      { style: objectAssign({
          WebkitTransform: 'translate3d(' + translate + 'px, 0, 0)',
          transform: 'translate3d(-' + translate + '%, 0, 0)'
        }, styles.container, style) },
      childrenToRender
    );
  },
  render: function render() {
    var _this = this;

    var _state = this.state;
    var index = _state.index;
    var isDragging = _state.isDragging;

    var springConfig = isDragging ? [3000, 50] : [300, 30];

    var style = {
      translate: spring(index * 100, springConfig)
    };

    return React.createElement(
      'div',
      { style: styles.root,
        onTouchStart: this.handleTouchStart, onTouchMove: this.handleTouchMove, onTouchEnd: this.handleTouchEnd },
      React.createElement(
        Motion,
        { style: style },
        function (value) {
          return _this.renderContainer(value.translate);
        }
      )
    );
  }
});

module.exports = SwipeableViews;
